@@ -10,13 +10,14 @@ import tmuxp
 # Get the project root dir, which is the parent dir of this
 cwd = Path(__file__).parent
 project_root = cwd.parent
+src_root = project_root / "src"
 
-sys.path.insert(0, str(project_root))
+sys.path.insert(0, str(src_root))
 sys.path.insert(0, str(cwd / "_ext"))
 
 # package data
 about: t.Dict[str, str] = {}
-with open(project_root / "tmuxp" / "__about__.py") as fp:
+with open(src_root / "tmuxp" / "__about__.py") as fp:
     exec(fp.read(), about)
 
 extensions = [
@@ -33,7 +34,6 @@ extensions = [
     "sphinxext.opengraph",
     "sphinxext.rediraffe",
     "myst_parser",
-    "sphinx_toctree_autodoc_fix",
     "linkify_issues",
 ]
 
@@ -82,6 +82,9 @@ html_theme_options: t.Dict[str, t.Union[str, t.List[t.Dict[str, str]]]] = {
             "class": "",
         },
     ],
+    "source_repository": f"{about['__github__']}/",
+    "source_branch": "master",
+    "source_directory": "docs/",
 }
 html_sidebars = {
     "**": [
@@ -95,7 +98,10 @@ html_sidebars = {
 }
 
 # linkify_issues
-issue_url_tpl = "https://github.com/tmux-python/tmuxp/issues/{issue_id}"
+issue_url_tpl = about["__github__"] + "/issues/{issue_id}"
+
+# sphinx.ext.autodoc
+toc_object_entries_show_parents = "hide"
 
 # sphinxext.opengraph
 ogp_site_url = about["__docs__"]
@@ -215,16 +221,18 @@ def linkcode_resolve(domain, info):  # NOQA: C901
     fn = relpath(fn, start=dirname(tmuxp.__file__))
 
     if "dev" in about["__version__"]:
-        return "{}/blob/master/{}/{}{}".format(
+        return "{}/blob/master/{}/{}/{}{}".format(
             about["__github__"],
+            "src",
             about["__package_name__"],
             fn,
             linespec,
         )
     else:
-        return "{}/blob/v{}/{}/{}{}".format(
+        return "{}/blob/v{}/{}/{}/{}{}".format(
             about["__github__"],
             about["__version__"],
+            "src",
             about["__package_name__"],
             fn,
             linespec,
